/****************************************************************************
** Meta object code from reading C++ file 'comicproviderwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeplasma-addons-6.7.4/applets/comic/engine/comicproviderwrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'comicproviderwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ImageWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN12ImageWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageWrapper",
        "imageCount",
        "",
        "read",
        "QImage",
        "image",
        "rawData"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'imageCount'
        QtMocHelpers::SlotData<int() const>(1, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'read'
        QtMocHelpers::SlotData<QImage()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'image'
        QtMocHelpers::PropertyData<QImage>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'rawData'
        QtMocHelpers::PropertyData<QByteArray>(6, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageWrapper, qt_meta_tag_ZN12ImageWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ImageWrapperE_t>.metaTypes,
    nullptr
} };

void ImageWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->imageCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { QImage _r = _t->read();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QImage*>(_v) = _t->image(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->rawData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImage(*reinterpret_cast<QImage*>(_v)); break;
        case 1: _t->setRawData(*reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ImageWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11DateWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto DateWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN11DateWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DateWrapper",
        "addDays",
        "",
        "ndays",
        "addMonths",
        "nmonths",
        "addYears",
        "nyears",
        "day",
        "dayOfWeek",
        "dayOfYear",
        "daysInMonth",
        "daysInYear",
        "daysTo",
        "QVariant",
        "d",
        "isNull",
        "isValid",
        "month",
        "setDate",
        "year",
        "toJulianDay",
        "weekNumber",
        "toString",
        "format",
        "date"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addDays'
        QtMocHelpers::SlotData<DateWrapper(int)>(1, 2, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'addMonths'
        QtMocHelpers::SlotData<DateWrapper(int)>(4, 2, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'addYears'
        QtMocHelpers::SlotData<DateWrapper(int)>(6, 2, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'day'
        QtMocHelpers::SlotData<int() const>(8, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'dayOfWeek'
        QtMocHelpers::SlotData<int() const>(9, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'dayOfYear'
        QtMocHelpers::SlotData<int() const>(10, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'daysInMonth'
        QtMocHelpers::SlotData<int() const>(11, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'daysInYear'
        QtMocHelpers::SlotData<int() const>(12, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'daysTo'
        QtMocHelpers::SlotData<int(const QVariant) const>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'isNull'
        QtMocHelpers::SlotData<bool() const>(16, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isValid'
        QtMocHelpers::SlotData<bool() const>(17, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'month'
        QtMocHelpers::SlotData<int() const>(18, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setDate'
        QtMocHelpers::SlotData<bool(int, int, int)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 18 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'toJulianDay'
        QtMocHelpers::SlotData<int() const>(21, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'weekNumber'
        QtMocHelpers::SlotData<int() const>(22, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'year'
        QtMocHelpers::SlotData<int() const>(20, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'toString'
        QtMocHelpers::MethodData<QString(const QString &) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'toString'
        QtMocHelpers::MethodData<QString(int) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 24 },
        }}),
        // Method 'toString'
        QtMocHelpers::MethodData<QString() const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'date'
        QtMocHelpers::PropertyData<QDate>(25, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DateWrapper, qt_meta_tag_ZN11DateWrapperE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DateWrapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DateWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DateWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DateWrapperE_t>.metaTypes,
    nullptr
} };

void DateWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<DateWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { DateWrapper _r = _t->addDays((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 1: { DateWrapper _r = _t->addMonths((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 2: { DateWrapper _r = _t->addYears((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->day();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->dayOfWeek();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->dayOfYear();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->daysInMonth();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->daysInYear();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->daysTo((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->isNull();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isValid();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->month();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setDate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->toJulianDay();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->weekNumber();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->year();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->toString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDate*>(_v) = _t->date(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDate(*reinterpret_cast<QDate*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17StaticDateWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto StaticDateWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN17StaticDateWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StaticDateWrapper",
        "currentDate",
        "DateWrapper",
        "",
        "fromJulianDay",
        "jd",
        "fromString",
        "string",
        "format",
        "isLeapYear",
        "year",
        "isValid",
        "month",
        "day",
        "longDayName",
        "weekday",
        "longMonthName",
        "shortDayName",
        "shortMonthName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'currentDate'
        QtMocHelpers::SlotData<DateWrapper()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'fromJulianDay'
        QtMocHelpers::SlotData<DateWrapper(int)>(4, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'fromString'
        QtMocHelpers::SlotData<DateWrapper(const QString &, int)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'fromString'
        QtMocHelpers::SlotData<DateWrapper(const QString &)>(6, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'fromString'
        QtMocHelpers::SlotData<DateWrapper(const QString &, const QString &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'isLeapYear'
        QtMocHelpers::SlotData<bool(int)>(9, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'isValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(11, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'longDayName'
        QtMocHelpers::SlotData<QString(int)>(14, 3, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'longMonthName'
        QtMocHelpers::SlotData<QString(int)>(16, 3, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'shortDayName'
        QtMocHelpers::SlotData<QString(int)>(17, 3, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'shortMonthName'
        QtMocHelpers::SlotData<QString(int)>(18, 3, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StaticDateWrapper, qt_meta_tag_ZN17StaticDateWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StaticDateWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17StaticDateWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17StaticDateWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17StaticDateWrapperE_t>.metaTypes,
    nullptr
} };

void StaticDateWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StaticDateWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { DateWrapper _r = _t->currentDate();
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 1: { DateWrapper _r = _t->fromJulianDay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 2: { DateWrapper _r = _t->fromString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 3: { DateWrapper _r = _t->fromString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 4: { DateWrapper _r = _t->fromString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DateWrapper*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->isLeapYear((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->longDayName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->longMonthName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->shortDayName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->shortMonthName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *StaticDateWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StaticDateWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17StaticDateWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StaticDateWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN20ComicProviderWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto ComicProviderWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN20ComicProviderWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComicProviderWrapper",
        "finished",
        "",
        "error",
        "requestPage",
        "url",
        "id",
        "QVariantMap",
        "infos",
        "requestRedirectedUrl",
        "combine",
        "QVariant",
        "image",
        "PositionType",
        "position",
        "init",
        "print",
        "QJSValue",
        "str",
        "identifierSpecified",
        "textCodec",
        "comicAuthor",
        "websiteUrl",
        "shopUrl",
        "title",
        "additionalText",
        "identifier",
        "nextIdentifier",
        "previousIdentifier",
        "firstIdentifier",
        "lastIdentifier",
        "isLeftToRight",
        "isTopToBottom",
        "apiVersion",
        "Left",
        "Top",
        "Right",
        "Bottom",
        "RedirectedUrlType",
        "PreviousUrl",
        "CurrentUrl",
        "NextUrl",
        "FirstUrl",
        "LastUrl",
        "UserUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'finished'
        QtMocHelpers::SlotData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'error'
        QtMocHelpers::SlotData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestPage'
        QtMocHelpers::SlotData<void(const QString &, int, const QVariantMap &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'requestPage'
        QtMocHelpers::SlotData<void(const QString &, int)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'requestRedirectedUrl'
        QtMocHelpers::SlotData<void(const QString &, int, const QVariantMap &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'requestRedirectedUrl'
        QtMocHelpers::SlotData<void(const QString &, int)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'combine'
        QtMocHelpers::SlotData<void(const QVariant &, enum PositionType)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'combine'
        QtMocHelpers::SlotData<void(const QVariant &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'image'
        QtMocHelpers::SlotData<QObject *()>(12, 2, QMC::AccessPublic, QMetaType::QObjectStar),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'print'
        QtMocHelpers::MethodData<void(const QJSValue &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identifierSpecified'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'textCodec'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'comicAuthor'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'websiteUrl'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shopUrl'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'additionalText'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'identifier'
        QtMocHelpers::PropertyData<QJSValue>(26, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'nextIdentifier'
        QtMocHelpers::PropertyData<QJSValue>(27, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'previousIdentifier'
        QtMocHelpers::PropertyData<QJSValue>(28, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'firstIdentifier'
        QtMocHelpers::PropertyData<QJSValue>(29, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'lastIdentifier'
        QtMocHelpers::PropertyData<QJSValue>(30, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'isLeftToRight'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isTopToBottom'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'apiVersion'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PositionType'
        QtMocHelpers::EnumData<enum PositionType>(13, 13, QMC::EnumFlags{}).add({
            {   34, PositionType::Left },
            {   35, PositionType::Top },
            {   36, PositionType::Right },
            {   37, PositionType::Bottom },
        }),
        // enum 'RedirectedUrlType'
        QtMocHelpers::EnumData<enum RedirectedUrlType>(38, 38, QMC::EnumFlags{}).add({
            {   39, RedirectedUrlType::PreviousUrl },
            {   40, RedirectedUrlType::CurrentUrl },
            {   41, RedirectedUrlType::NextUrl },
            {   42, RedirectedUrlType::FirstUrl },
            {   43, RedirectedUrlType::LastUrl },
            {   44, RedirectedUrlType::UserUrl },
        }),
    };
    return QtMocHelpers::metaObjectData<ComicProviderWrapper, qt_meta_tag_ZN20ComicProviderWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ComicProviderWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ComicProviderWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ComicProviderWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ComicProviderWrapperE_t>.metaTypes,
    nullptr
} };

void ComicProviderWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComicProviderWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->error(); break;
        case 2: _t->requestPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 3: _t->requestPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->requestRedirectedUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 5: _t->requestRedirectedUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->combine((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum PositionType>>(_a[2]))); break;
        case 7: _t->combine((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 8: { QObject* _r = _t->image();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->init(); break;
        case 10: _t->print((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
        case 10:
        case 9:
        case 8:
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->identifierSpecified(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->textCodec(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->comicAuthor(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->websiteUrl(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->shopUrl(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->additionalText(); break;
        case 7: *reinterpret_cast<QJSValue*>(_v) = _t->identifier(); break;
        case 8: *reinterpret_cast<QJSValue*>(_v) = _t->nextIdentifier(); break;
        case 9: *reinterpret_cast<QJSValue*>(_v) = _t->previousIdentifier(); break;
        case 10: *reinterpret_cast<QJSValue*>(_v) = _t->firstIdentifier(); break;
        case 11: *reinterpret_cast<QJSValue*>(_v) = _t->lastIdentifier(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isLeftToRight(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isTopToBottom(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->apiVersion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTextCodec(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setComicAuthor(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setWebsiteUrl(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setShopUrl(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setAdditionalText(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setIdentifier(*reinterpret_cast<QJSValue*>(_v)); break;
        case 8: _t->setNextIdentifier(*reinterpret_cast<QJSValue*>(_v)); break;
        case 9: _t->setPreviousIdentifier(*reinterpret_cast<QJSValue*>(_v)); break;
        case 10: _t->setFirstIdentifier(*reinterpret_cast<QJSValue*>(_v)); break;
        case 11: _t->setLastIdentifier(*reinterpret_cast<QJSValue*>(_v)); break;
        case 12: _t->setLeftToRight(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setTopToBottom(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ComicProviderWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComicProviderWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ComicProviderWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ComicProviderWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
