// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "wettercom_debug.h"

 namespace WEATHER { namespace ION {
Q_LOGGING_CATEGORY(WETTERCOM, "org.kde.weather.ion.wettercom", QtInfoMsg)
} } 
