/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<documenthandler.h>)
#  include <documenthandler.h>
#endif
#if __has_include(<note.h>)
#  include <note.h>
#endif
#if __has_include(<notemanager.h>)
#  include <notemanager.h>
#endif
#if __has_include(<noteshelper.h>)
#  include <noteshelper.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_plasma_applet_org_kde_plasma_notes()
{
    qmlRegisterModule("plasma.applet.org.kde.plasma.notes", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DocumentHandler>("plasma.applet.org.kde.plasma.notes", 254);
    qmlRegisterTypesAndRevisions<Note>("plasma.applet.org.kde.plasma.notes", 254);
    qmlRegisterTypesAndRevisions<NoteManager>("plasma.applet.org.kde.plasma.notes", 254);
    qmlRegisterTypesAndRevisions<NotesHelper>("plasma.applet.org.kde.plasma.notes", 254);
    QT_WARNING_POP
    qmlRegisterModule("plasma.applet.org.kde.plasma.notes", 254, 254);
}

static const QQmlModuleRegistration plasmaappletorgkdeplasmanotesRegistration("plasma.applet.org.kde.plasma.notes", qml_register_types_plasma_applet_org_kde_plasma_notes);
