/****************************************************************************
** Meta object code from reading C++ file 'quicklaunch_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.4/applets/quicklaunch/quicklaunch_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quicklaunch_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QuicklaunchPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QuicklaunchPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN18QuicklaunchPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QuicklaunchPrivate",
        "QML.Element",
        "Logic",
        "launcherAdded",
        "",
        "url",
        "isPopup",
        "launcherEdited",
        "index",
        "launcherData",
        "QVariantMap",
        "QUrl",
        "openUrl",
        "openExec",
        "exec",
        "addLauncher",
        "editLauncher"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'launcherAdded'
        QtMocHelpers::SignalData<void(const QString &, bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'launcherEdited'
        QtMocHelpers::SignalData<void(const QString &, int, bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 8 }, { QMetaType::Bool, 6 },
        }}),
        // Method 'launcherData'
        QtMocHelpers::MethodData<QVariantMap(const QUrl &)>(9, 4, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 11, 5 },
        }}),
        // Method 'openUrl'
        QtMocHelpers::MethodData<void(const QUrl &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 5 },
        }}),
        // Method 'openExec'
        QtMocHelpers::MethodData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'addLauncher'
        QtMocHelpers::MethodData<void(bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Method 'addLauncher'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'editLauncher'
        QtMocHelpers::MethodData<void(QUrl, int, bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 5 }, { QMetaType::Int, 8 }, { QMetaType::Bool, 6 },
        }}),
        // Method 'editLauncher'
        QtMocHelpers::MethodData<void(QUrl, int)>(16, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 11, 5 }, { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QuicklaunchPrivate, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QuicklaunchPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QuicklaunchPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QuicklaunchPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QuicklaunchPrivateE_t>.metaTypes,
    nullptr
} };

void QuicklaunchPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuicklaunchPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->launcherAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->launcherEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: { QVariantMap _r = _t->launcherData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->openExec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->addLauncher((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->addLauncher(); break;
        case 7: _t->editLauncher((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->editLauncher((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QuicklaunchPrivate::*)(const QString & , bool )>(_a, &QuicklaunchPrivate::launcherAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuicklaunchPrivate::*)(const QString & , int , bool )>(_a, &QuicklaunchPrivate::launcherEdited, 1))
            return;
    }
}

const QMetaObject *QuicklaunchPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QuicklaunchPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QuicklaunchPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QuicklaunchPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QuicklaunchPrivate::launcherAdded(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QuicklaunchPrivate::launcherEdited(const QString & _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
