/****************************************************************************
** Meta object code from reading C++ file 'potdbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeplasma-addons-6.7.4/wallpapers/potd/plugins/potdbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'potdbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PotdBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto PotdBackend::qt_create_metaobjectdata<qt_meta_tag_ZN11PotdBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PotdBackend",
        "QML.Element",
        "auto",
        "identifierChanged",
        "",
        "argumentsChanged",
        "imageChanged",
        "loadingChanged",
        "localUrlChanged",
        "infoUrlChanged",
        "remoteUrlChanged",
        "titleChanged",
        "authorChanged",
        "saveStatusChanged",
        "updateOverMeteredConnectionChanged",
        "saveImage",
        "identifier",
        "arguments",
        "QVariantList",
        "loading",
        "localUrl",
        "infoUrl",
        "QUrl",
        "remoteUrl",
        "title",
        "author",
        "saveStatus",
        "FileOperationStatus",
        "saveStatusMessage",
        "savedFolder",
        "savedUrl",
        "networkInformationAvailable",
        "updateOverMeteredConnection",
        "None",
        "Successful",
        "Failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'argumentsChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localUrlChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'infoUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remoteUrlChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveStatusChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateOverMeteredConnectionChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'saveImage'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identifier'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'arguments'
        QtMocHelpers::PropertyData<QVariantList>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'localUrl'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'infoUrl'
        QtMocHelpers::PropertyData<QUrl>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'remoteUrl'
        QtMocHelpers::PropertyData<QUrl>(23, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'saveStatus'
        QtMocHelpers::PropertyData<enum FileOperationStatus>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 9),
        // property 'saveStatusMessage'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'savedFolder'
        QtMocHelpers::PropertyData<QUrl>(29, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'savedUrl'
        QtMocHelpers::PropertyData<QUrl>(30, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'networkInformationAvailable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'updateOverMeteredConnection'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FileOperationStatus'
        QtMocHelpers::EnumData<enum FileOperationStatus>(27, 27, QMC::EnumIsScoped).add({
            {   33, FileOperationStatus::None },
            {   34, FileOperationStatus::Successful },
            {   35, FileOperationStatus::Failed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PotdBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PotdBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PotdBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PotdBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PotdBackendE_t>.metaTypes,
    nullptr
} };

void PotdBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PotdBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->identifierChanged(); break;
        case 1: _t->argumentsChanged(); break;
        case 2: _t->imageChanged(); break;
        case 3: _t->loadingChanged(); break;
        case 4: _t->localUrlChanged(); break;
        case 5: _t->infoUrlChanged(); break;
        case 6: _t->remoteUrlChanged(); break;
        case 7: _t->titleChanged(); break;
        case 8: _t->authorChanged(); break;
        case 9: _t->saveStatusChanged(); break;
        case 10: _t->updateOverMeteredConnectionChanged(); break;
        case 11: _t->saveImage(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::identifierChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::argumentsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::imageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::loadingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::localUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::infoUrlChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::remoteUrlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::titleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::authorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::saveStatusChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PotdBackend::*)()>(_a, &PotdBackend::updateOverMeteredConnectionChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->identifier(); break;
        case 1: *reinterpret_cast<QVariantList*>(_v) = _t->arguments(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->localUrl(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->infoUrl(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->remoteUrl(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 8: *reinterpret_cast<enum FileOperationStatus*>(_v) = _t->m_saveStatus; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->m_saveStatusMessage; break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->m_savedFolder; break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->m_savedUrl; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->m_networkInfomationAvailable; break;
        case 13: *reinterpret_cast<int*>(_v) = _t->doesUpdateOverMeteredConnection(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentifier(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setArguments(*reinterpret_cast<QVariantList*>(_v)); break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_saveStatus, *reinterpret_cast<enum FileOperationStatus*>(_v)))
                Q_EMIT _t->saveStatusChanged();
            break;
        case 13: _t->setUpdateOverMeteredConnection(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PotdBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PotdBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PotdBackendE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int PotdBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PotdBackend::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PotdBackend::argumentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PotdBackend::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PotdBackend::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PotdBackend::localUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PotdBackend::infoUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PotdBackend::remoteUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PotdBackend::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PotdBackend::authorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PotdBackend::saveStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PotdBackend::updateOverMeteredConnectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
