/****************************************************************************
** Meta object code from reading C++ file 'comicdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.4/applets/comic/comicdata.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'comicdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ComicDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ComicData::qt_create_metaobjectdata<qt_meta_tag_ZN9ComicDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComicData",
        "QML.Element",
        "comicData",
        "saveImage",
        "",
        "QUrl",
        "fileUrl",
        "launchShop",
        "launchWebsite",
        "type",
        "Type",
        "id",
        "image",
        "QImage",
        "prev",
        "next",
        "additionalText",
        "websiteUrl",
        "websiteHost",
        "shopUrl",
        "first",
        "hasFirst",
        "stripTitle",
        "author",
        "title",
        "current",
        "currentReadable",
        "firstStripNum",
        "maxStripNum",
        "isLeftToRight",
        "isTopToBottom",
        "isError",
        "storePosition",
        "ready",
        "DateIdentifier",
        "NumberIdentifier",
        "StringIdentifier"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'saveImage'
        QtMocHelpers::MethodData<bool(const QUrl &)>(3, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'launchShop'
        QtMocHelpers::MethodData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'launchWebsite'
        QtMocHelpers::MethodData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'image'
        QtMocHelpers::PropertyData<QImage>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'prev'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'next'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'additionalText'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'websiteUrl'
        QtMocHelpers::PropertyData<QUrl>(17, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'websiteHost'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'shopUrl'
        QtMocHelpers::PropertyData<QUrl>(19, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'first'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'hasFirst'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'stripTitle'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'current'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'currentReadable'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'firstStripNum'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'maxStripNum'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'isLeftToRight'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isTopToBottom'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isError'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'storePosition'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(10, 10, QMC::EnumIsScoped).add({
            {   34, Type::DateIdentifier },
            {   35, Type::NumberIdentifier },
            {   36, Type::StringIdentifier },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ComicData, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ComicData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ComicDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ComicDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ComicDataE_t>.metaTypes,
    nullptr
} };

void ComicData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ComicData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->saveImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->launchShop(); break;
        case 2: _t->launchWebsite(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Type*>(_v) = _t->typeForQml(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 2: *reinterpret_cast<QImage*>(_v) = _t->image(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->prev(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->next(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->additionalText(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->websiteUrl(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->websiteHost(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->shopUrl(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->first(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasFirst(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->stripTitle(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->current(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->currentReadable(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->firstStripNum(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->maxStripNum(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isLeftToRight(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isTopToBottom(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isError(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->storePosition(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->ready(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
