/****************************************************************************
** Meta object code from reading C++ file 'forecast.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeplasma-addons-6.7.4/applets/weather/weatherdata/forecast.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'forecast.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ForecastE_t {};
} // unnamed namespace

template <> constexpr inline auto Forecast::qt_create_metaobjectdata<qt_meta_tag_ZN8ForecastE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Forecast",
        "station",
        "QVariant",
        "metaData",
        "lastObservation",
        "lastDay",
        "currentDay",
        "warnings",
        "Warnings*",
        "futureDays",
        "FutureDays*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'station'
        QtMocHelpers::PropertyData<QVariant>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'metaData'
        QtMocHelpers::PropertyData<QVariant>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastObservation'
        QtMocHelpers::PropertyData<QVariant>(4, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastDay'
        QtMocHelpers::PropertyData<QVariant>(5, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentDay'
        QtMocHelpers::PropertyData<QVariant>(6, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'warnings'
        QtMocHelpers::PropertyData<Warnings*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'futureDays'
        QtMocHelpers::PropertyData<FutureDays*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Forecast, qt_meta_tag_ZN8ForecastE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Forecast::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ForecastE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ForecastE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ForecastE_t>.metaTypes,
    nullptr
} };

void Forecast::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Forecast *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FutureDays* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Warnings* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->station(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->metaData(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->lastObservation(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->lastDay(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->currentDay(); break;
        case 5: *reinterpret_cast<Warnings**>(_v) = _t->warnings(); break;
        case 6: *reinterpret_cast<FutureDays**>(_v) = _t->futureDays(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
