/********************************************************************************
** Form generated from reading UI file 'cubeeffectkcm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUBEEFFECTKCM_H
#define UI_CUBEEFFECTKCM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kshortcutseditor.h"

QT_BEGIN_NAMESPACE

class Ui_CubeEffectConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label_2;
    QGridLayout *gridLayout;
    QSlider *kcfg_CubeFaceDisplacement;
    QLabel *label_less;
    QLabel *label_more;
    QLabel *label;
    QGridLayout *gridLayout_2;
    QSlider *slider_DistanceFactor;
    QLabel *label_closer;
    QLabel *label_farther;
    QLabel *label_Mouse;
    QCheckBox *kcfg_MouseInvertedX;
    QCheckBox *kcfg_MouseInvertedY;
    QLabel *label_4;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QRadioButton *button_Color;
    KColorButton *kcfg_BackgroundColor;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *button_SkyBox;
    QLineEdit *kcfg_SkyBox;
    QPushButton *button_SelectSkyBox;
    KShortcutsEditor *shortcutsEditor;

    void setupUi(QWidget *CubeEffectConfig)
    {
        if (CubeEffectConfig->objectName().isEmpty())
            CubeEffectConfig->setObjectName("CubeEffectConfig");
        CubeEffectConfig->resize(455, 361);
        CubeEffectConfig->setMinimumSize(QSize(400, 250));
        formLayout = new QFormLayout(CubeEffectConfig);
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(CubeEffectConfig);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        kcfg_CubeFaceDisplacement = new QSlider(CubeEffectConfig);
        kcfg_CubeFaceDisplacement->setObjectName("kcfg_CubeFaceDisplacement");
        kcfg_CubeFaceDisplacement->setMaximum(300);
        kcfg_CubeFaceDisplacement->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(kcfg_CubeFaceDisplacement, 0, 0, 1, 2);

        label_less = new QLabel(CubeEffectConfig);
        label_less->setObjectName("label_less");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_less->sizePolicy().hasHeightForWidth());
        label_less->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_less, 1, 0, 1, 1);

        label_more = new QLabel(CubeEffectConfig);
        label_more->setObjectName("label_more");
        sizePolicy.setHeightForWidth(label_more->sizePolicy().hasHeightForWidth());
        label_more->setSizePolicy(sizePolicy);
        label_more->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_more, 1, 1, 1, 1);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, gridLayout);

        label = new QLabel(CubeEffectConfig);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        slider_DistanceFactor = new QSlider(CubeEffectConfig);
        slider_DistanceFactor->setObjectName("slider_DistanceFactor");
        slider_DistanceFactor->setMinimum(100);
        slider_DistanceFactor->setMaximum(300);
        slider_DistanceFactor->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(slider_DistanceFactor, 0, 0, 1, 2);

        label_closer = new QLabel(CubeEffectConfig);
        label_closer->setObjectName("label_closer");
        sizePolicy.setHeightForWidth(label_closer->sizePolicy().hasHeightForWidth());
        label_closer->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_closer, 1, 0, 1, 1);

        label_farther = new QLabel(CubeEffectConfig);
        label_farther->setObjectName("label_farther");
        sizePolicy.setHeightForWidth(label_farther->sizePolicy().hasHeightForWidth());
        label_farther->setSizePolicy(sizePolicy);
        label_farther->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_farther, 1, 1, 1, 1);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, gridLayout_2);

        label_Mouse = new QLabel(CubeEffectConfig);
        label_Mouse->setObjectName("label_Mouse");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_Mouse);

        kcfg_MouseInvertedX = new QCheckBox(CubeEffectConfig);
        kcfg_MouseInvertedX->setObjectName("kcfg_MouseInvertedX");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_MouseInvertedX);

        kcfg_MouseInvertedY = new QCheckBox(CubeEffectConfig);
        kcfg_MouseInvertedY->setObjectName("kcfg_MouseInvertedY");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_MouseInvertedY);

        label_4 = new QLabel(CubeEffectConfig);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        button_Color = new QRadioButton(CubeEffectConfig);
        button_Color->setObjectName("button_Color");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(button_Color->sizePolicy().hasHeightForWidth());
        button_Color->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(button_Color);

        kcfg_BackgroundColor = new KColorButton(CubeEffectConfig);
        kcfg_BackgroundColor->setObjectName("kcfg_BackgroundColor");
        kcfg_BackgroundColor->setEnabled(false);
        kcfg_BackgroundColor->setFlat(false);

        horizontalLayout->addWidget(kcfg_BackgroundColor);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        button_SkyBox = new QRadioButton(CubeEffectConfig);
        button_SkyBox->setObjectName("button_SkyBox");

        horizontalLayout_2->addWidget(button_SkyBox);

        kcfg_SkyBox = new QLineEdit(CubeEffectConfig);
        kcfg_SkyBox->setObjectName("kcfg_SkyBox");
        kcfg_SkyBox->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_SkyBox);

        button_SelectSkyBox = new QPushButton(CubeEffectConfig);
        button_SelectSkyBox->setObjectName("button_SelectSkyBox");
        button_SelectSkyBox->setEnabled(false);

        horizontalLayout_2->addWidget(button_SelectSkyBox);


        verticalLayout_3->addLayout(horizontalLayout_2);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, verticalLayout_3);

        shortcutsEditor = new KShortcutsEditor(CubeEffectConfig);
        shortcutsEditor->setObjectName("shortcutsEditor");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(shortcutsEditor->sizePolicy().hasHeightForWidth());
        shortcutsEditor->setSizePolicy(sizePolicy2);

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, shortcutsEditor);


        retranslateUi(CubeEffectConfig);
        QObject::connect(button_SkyBox, &QRadioButton::toggled, button_SelectSkyBox, &QPushButton::setEnabled);
        QObject::connect(button_SkyBox, &QRadioButton::toggled, kcfg_SkyBox, &QLineEdit::setEnabled);
        QObject::connect(button_Color, SIGNAL(toggled(bool)), kcfg_BackgroundColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CubeEffectConfig);
    } // setupUi

    void retranslateUi(QWidget *CubeEffectConfig)
    {
        label_2->setText(tr2i18n("Cube face displacement:", nullptr));
        label_less->setText(tr2i18n("Less", nullptr));
        label_more->setText(tr2i18n("More", nullptr));
        label->setText(tr2i18n("Distance:", nullptr));
        label_closer->setText(tr2i18n("Closer", nullptr));
        label_farther->setText(tr2i18n("Farther", nullptr));
        label_Mouse->setText(tr2i18n("Mouse:", nullptr));
        kcfg_MouseInvertedX->setText(tr2i18n("Invert X", nullptr));
        kcfg_MouseInvertedY->setText(tr2i18n("Invert Y", nullptr));
        label_4->setText(tr2i18n("Background:", nullptr));
        button_Color->setText(tr2i18n("Plain color:", nullptr));
        button_SkyBox->setText(tr2i18n("Skybox:", nullptr));
        kcfg_SkyBox->setPlaceholderText(tr2i18n("Type path or URL...", nullptr));
        button_SelectSkyBox->setText(tr2i18n("Select...", nullptr));
        (void)CubeEffectConfig;
    } // retranslateUi

};

namespace Ui {
    class CubeEffectConfig: public Ui_CubeEffectConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUBEEFFECTKCM_H

