// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "weathercontroller_debug.h"

 namespace WEATHER {
Q_LOGGING_CATEGORY(CONTROLLER, "org.kde.applets.weather.controller", QtInfoMsg)
} 
