/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // main.xml
  0x0,0x0,0x1,0xcc,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x33,0x5,0x15,0xe,0x0,0xb6,0xd4,0x41,0x1f,0x20,0xb1,0x1e,
  0xf3,0x10,0xc,0x52,0xec,0x95,0xee,0x66,0xff,0x4d,0xd1,0xd8,0x47,0xe,0x3a,0x6e,
  0x66,0x6e,0xf3,0x1a,0x85,0x55,0x10,0x4,0x18,0x80,0x64,0xd1,0x39,0x0,0x38,0x0,
  0x39,0x0,0x9c,0xc4,0x7b,0x62,0xc4,0xf4,0x4e,0xfa,0x33,0xe3,0x58,0xaf,0x8d,0x9a,
  0x66,0xa2,0xae,0xeb,0x62,0x4c,0x70,0x39,0x67,0x90,0xc2,0xff,0x2a,0x76,0x65,0xa6,
  0xa7,0x52,0xc0,0x3,0xe0,0x61,0x5d,0x20,0x55,0xdf,0xa9,0xbd,0xbe,0x1f,0x94,0x51,
  0x0,0x52,0x6f,0x1d,0xdf,0xde,0x3c,0x6d,0xe3,0x28,0xa6,0x16,0xed,0x77,0xac,0x69,
  0x5f,0xae,0x73,0xf3,0x37,0xd4,0xe6,0xed,0x6f,0x8,0xa7,0xb1,0xb7,0x3e,0x55,0x84,
  0x90,0xea,0x6d,0xfe,0x6b,0xcd,0xb1,0xea,0x41,0x8a,0x39,0x51,0x9e,0x97,0x8d,0xe0,
  0x84,0xe3,0xbe,0xde,0x1,0x73,0xeb,0xec,0xb2,0x44,0x24,0x98,0x18,0x90,0x52,0x20,
  0x75,0x8e,0x3,0xf,0x76,0x9e,0x8e,0xbc,0xa0,0xbd,0x99,0x98,0xbe,0xbd,0x1a,0xbf,
  0xd7,0xf7,0x7f,0xcd,0x7d,0xaa,0x18,0x27,0xc9,0x20,0x38,0x10,0x24,0x2,0x92,0x84,
  0x1,0x24,0xa5,0x4,0x49,0x41,0x0,0x92,0x5,0x48,0x4a,0x55,0xd6,0x34,0x33,0x63,
  0x8f,0xd4,0xf7,0x9b,0x2d,0x5c,0x27,0x3f,0x88,0x6f,0x6f,0x1e,0xcf,0x53,0x55,0xec,
  0xca,0xc4,0xe9,0xa9,0x2e,0xfa,0x73,0xdb,0x6c,0x83,0x76,0x86,0xfd,0x1d,0x7b,0x99,
  0xd3,0xd6,0x3b,0xe6,0xd9,0x4e,0xee,0x64,0x60,0xdc,0xb7,0xda,0x4b,0xd1,0x6a,0xb5,
  0x96,0xa5,0x35,0x37,0xfb,0xdc,0xba,0x92,0x1b,0x6b,0x13,0xb3,0x96,0xd1,0x5a,0x76,
  0xab,0xb3,0x59,0x4d,0xa0,0x81,0x21,0x24,0xc6,0x86,0x46,0x52,0x94,0x62,0xe9,0x40,
  0x84,0x10,0x72,0xec,0xea,0xfd,0x24,0xe1,0x5,0x29,0x80,0xe4,0x6e,0xbd,0x92,0xa5,
  0x7a,0x6c,0xd4,0x54,0xb5,0x34,0x5b,0xa,0x3d,0x6d,0x30,0xce,0xdd,0x40,0x25,0x85,
  0xa0,0xef,0x56,0xab,0xc2,0xa0,0xe3,0xb5,0xa0,0xea,0x5,0x58,0xb,0x22,0xe3,0xdc,
  0xc,0xd6,0xa4,0xb6,0xfc,0x5b,0xd,0x6c,0xb7,0x7e,0x25,0x0,0x35,0xed,0xcb,0x5e,
  0xae,0x93,0x56,0x65,0xf3,0xc4,0x90,0x82,0xf5,0xc1,0x88,0xbd,0x73,0xe2,0x58,0x17,
  0xdf,0x6c,0x3e,0x6b,0x31,0x88,0x7d,0xe,0x3d,0x2f,0xca,0x20,0xb,0xfc,0x65,0x88,
  0x70,0x5,0x2f,0x84,0x9a,0x3,0x6e,0x9f,0x6e,0x80,0x80,0x31,0xa0,0x83,0x82,0x18,
  0x13,0xb8,0xc4,0x28,0x6,0x3b,0x82,0xee,0x85,0xf3,0x32,0x74,0x11,0x3c,0xb2,0x5c,
  0x10,0x93,0x82,0x5c,0xf2,0x51,0xcd,0xb6,0x5a,0xdb,0x6,0xe0,0x2e,0x9e,0x78,0x2c,
  0x1b,0x90,0xcf,0xd2,0xe2,0xee,0xc5,0xcf,0x52,0x2e,0x88,0x68,0x2f,0xdb,0x9f,0x97,
  0x5e,0x60,0x4f,0xe9,0x76,0x61,0xae,0x6a,0x1d,0xb0,0xaa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // applet
  0x0,0x6,
  0x6,0x87,0x72,0xc4,
  0x0,0x61,
  0x0,0x70,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // timer
  0x0,0x5,
  0x0,0x7b,0x3,0xc2,
  0x0,0x74,
  0x0,0x69,0x0,0x6d,0x0,0x65,0x0,0x72,
    // main.xml
  0x0,0x8,
  0x8,0x1,0x51,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet/org
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet/org/kde
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet/org/kde/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x8,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet/org/kde/plasma/timer
  0x0,0x0,0x0,0x52,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,
  // :/qt/qml/plasma/applet/org/kde/plasma/timer/main.xml
  0x0,0x0,0x0,0x62,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xce,0xdb,0x57,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_timer_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_timer_raw_res_1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_timer_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_timer_raw_res_1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_timer_raw_res_1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_timer_raw_res_1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
