/****************************************************************************
** Meta object code from reading C++ file 'lastobservation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeplasma-addons-6.7.4/applets/weather/weatherdata/lastobservation.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lastobservation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15LastObservationE_t {};
} // unnamed namespace

template <> constexpr inline auto LastObservation::qt_create_metaobjectdata<qt_meta_tag_ZN15LastObservationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LastObservation",
        "observationTimestamp",
        "QVariant",
        "currentConditions",
        "conditionIcon",
        "temperature",
        "windchill",
        "heatIndex",
        "humidex",
        "windSpeed",
        "windGust",
        "windDirection",
        "visibility",
        "pressure",
        "pressureTendency",
        "UVIndex",
        "UVRating",
        "humidity",
        "dewpoint"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'observationTimestamp'
        QtMocHelpers::PropertyData<QVariant>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentConditions'
        QtMocHelpers::PropertyData<QVariant>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'conditionIcon'
        QtMocHelpers::PropertyData<QVariant>(4, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'temperature'
        QtMocHelpers::PropertyData<QVariant>(5, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'windchill'
        QtMocHelpers::PropertyData<QVariant>(6, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'heatIndex'
        QtMocHelpers::PropertyData<QVariant>(7, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'humidex'
        QtMocHelpers::PropertyData<QVariant>(8, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'windSpeed'
        QtMocHelpers::PropertyData<QVariant>(9, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'windGust'
        QtMocHelpers::PropertyData<QVariant>(10, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'windDirection'
        QtMocHelpers::PropertyData<QVariant>(11, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'visibility'
        QtMocHelpers::PropertyData<QVariant>(12, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pressure'
        QtMocHelpers::PropertyData<QVariant>(13, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pressureTendency'
        QtMocHelpers::PropertyData<QVariant>(14, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'UVIndex'
        QtMocHelpers::PropertyData<QVariant>(15, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'UVRating'
        QtMocHelpers::PropertyData<QVariant>(16, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'humidity'
        QtMocHelpers::PropertyData<QVariant>(17, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'dewpoint'
        QtMocHelpers::PropertyData<QVariant>(18, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LastObservation, qt_meta_tag_ZN15LastObservationE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LastObservation::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15LastObservationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15LastObservationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15LastObservationE_t>.metaTypes,
    nullptr
} };

void LastObservation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<LastObservation *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->observationTimestamp(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->currentConditions(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->conditionIcon(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->temperature(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->windchill(); break;
        case 5: *reinterpret_cast<QVariant*>(_v) = _t->heatIndex(); break;
        case 6: *reinterpret_cast<QVariant*>(_v) = _t->humidex(); break;
        case 7: *reinterpret_cast<QVariant*>(_v) = _t->windSpeed(); break;
        case 8: *reinterpret_cast<QVariant*>(_v) = _t->windGust(); break;
        case 9: *reinterpret_cast<QVariant*>(_v) = _t->windDirection(); break;
        case 10: *reinterpret_cast<QVariant*>(_v) = _t->visibility(); break;
        case 11: *reinterpret_cast<QVariant*>(_v) = _t->pressure(); break;
        case 12: *reinterpret_cast<QVariant*>(_v) = _t->pressureTendency(); break;
        case 13: *reinterpret_cast<QVariant*>(_v) = _t->UVIndex(); break;
        case 14: *reinterpret_cast<QVariant*>(_v) = _t->UVRating(); break;
        case 15: *reinterpret_cast<QVariant*>(_v) = _t->humidity(); break;
        case 16: *reinterpret_cast<QVariant*>(_v) = _t->dewpoint(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
