/********************************************************************************
** Form generated from reading UI file 'spellcheck_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPELLCHECK_CONFIG_H
#define UI_SPELLCHECK_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpellCheckConfigUi
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *m_requireTriggerWord;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *m_triggerWord;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_openKcmButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SpellCheckConfigUi)
    {
        if (SpellCheckConfigUi->objectName().isEmpty())
            SpellCheckConfigUi->setObjectName("SpellCheckConfigUi");
        SpellCheckConfigUi->resize(327, 315);
        verticalLayout_2 = new QVBoxLayout(SpellCheckConfigUi);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(SpellCheckConfigUi);
        groupBox->setObjectName("groupBox");
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_requireTriggerWord = new QCheckBox(groupBox);
        m_requireTriggerWord->setObjectName("m_requireTriggerWord");

        verticalLayout_3->addWidget(m_requireTriggerWord);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_triggerWord = new QLineEdit(groupBox);
        m_triggerWord->setObjectName("m_triggerWord");

        horizontalLayout->addWidget(m_triggerWord);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        m_openKcmButton = new QPushButton(groupBox);
        m_openKcmButton->setObjectName("m_openKcmButton");

        horizontalLayout_2->addWidget(m_openKcmButton);


        verticalLayout_3->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 193, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        verticalLayout_2->addWidget(groupBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(m_triggerWord);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SpellCheckConfigUi);

        QMetaObject::connectSlotsByName(SpellCheckConfigUi);
    } // setupUi

    void retranslateUi(QWidget *SpellCheckConfigUi)
    {
        groupBox->setTitle(tr2i18n("Spell Check Settings", nullptr));
        m_requireTriggerWord->setText(tr2i18n("&Require trigger word", nullptr));
        label->setText(tr2i18n("&Trigger word:", nullptr));
        m_openKcmButton->setText(tr2i18n("Configure Dictionaries\342\200\246", nullptr));
        (void)SpellCheckConfigUi;
    } // retranslateUi

};

namespace Ui {
    class SpellCheckConfigUi: public Ui_SpellCheckConfigUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPELLCHECK_CONFIG_H

