/****************************************************************************
** Meta object code from reading C++ file 'dict_object.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.4/applets/dict/plugin/dict_object.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dict_object.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DictObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto DictObject::qt_create_metaobjectdata<qt_meta_tag_ZN10DictObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DictObject",
        "searchInProgress",
        "",
        "definitionFound",
        "html",
        "hasErrorChanged",
        "errorCodeChanged",
        "errorStringChanged",
        "lookup",
        "word",
        "slotDictErrorOccurred",
        "QAbstractSocket::SocketError",
        "socketError",
        "errorString",
        "webProfile",
        "QQuickWebEngineProfile*",
        "selectedDictionary",
        "hasError",
        "errorCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchInProgress'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'definitionFound'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'hasErrorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorCodeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorStringChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lookup'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotDictErrorOccurred'
        QtMocHelpers::SlotData<void(QAbstractSocket::SocketError, const QString &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'webProfile'
        QtMocHelpers::PropertyData<QQuickWebEngineProfile*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'selectedDictionary'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasError'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'errorCode'
        QtMocHelpers::PropertyData<QAbstractSocket::SocketError>(18, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DictObject, qt_meta_tag_ZN10DictObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN10DictObjectE[] = {
    QMetaObject::SuperData::link<QAbstractSocket::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DictObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DictObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DictObjectE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN10DictObjectE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DictObjectE_t>.metaTypes,
    nullptr
} };

void DictObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DictObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchInProgress(); break;
        case 1: _t->definitionFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->hasErrorChanged(); break;
        case 3: _t->errorCodeChanged(); break;
        case 4: _t->errorStringChanged(); break;
        case 5: _t->lookup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->slotDictErrorOccurred((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DictObject::*)()>(_a, &DictObject::searchInProgress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DictObject::*)(const QString & )>(_a, &DictObject::definitionFound, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DictObject::*)()>(_a, &DictObject::hasErrorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DictObject::*)()>(_a, &DictObject::errorCodeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DictObject::*)()>(_a, &DictObject::errorStringChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickWebEngineProfile* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickWebEngineProfile**>(_v) = _t->webProfile(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->selectedDictionary(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasError(); break;
        case 3: *reinterpret_cast<QAbstractSocket::SocketError*>(_v) = _t->errorCode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSelectedDictionary(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DictObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DictObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DictObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DictObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DictObject::searchInProgress()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DictObject::definitionFound(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DictObject::hasErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DictObject::errorCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DictObject::errorStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
